==> blesta-5.10.2.zip: blesta/components/modules/direct_admin/language/tr_tr/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'İstatistiki bilgiler şu anda mevcut değildir.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Değer';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Saha';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Bilgi';
$lang['DirectAdmin.tab_client_stats'] = 'İstatistikler';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Şifre';
$lang['DirectAdmin.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['DirectAdmin.edit_row.notes_title'] = 'Notlar';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Kaldırmak';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['DirectAdmin.edit_row.name_server_col'] = 'İsim Sunucusu';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'İsim Sunucuları';
$lang['DirectAdmin.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['DirectAdmin.edit_row.box_title'] = 'DirectAdmin Sunucusunu Düzenleme';
$lang['DirectAdmin.add_row.add_btn'] = 'Sunucu Ekle';
$lang['DirectAdmin.add_row.notes_title'] = 'Notlar';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Kaldırmak';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['DirectAdmin.add_row.name_server_col'] = 'İsim Sunucusu';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['DirectAdmin.add_row.name_servers_title'] = 'İsim Sunucuları';
$lang['DirectAdmin.add_row.basic_title'] = 'Temel Ayarlar';
$lang['DirectAdmin.add_row.box_title'] = 'DirectAdmin Sunucusu Ekleme';
$lang['DirectAdmin.row_meta.name_server'] = 'İsim sunucusu %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Hesap Limiti';
$lang['DirectAdmin.row_meta.use_ssl'] = 'API\'ye bağlanırken SSL kullanın (önerilir)';
$lang['DirectAdmin.row_meta.password'] = 'Şifre';
$lang['DirectAdmin.row_meta.user_name'] = 'Kullanıcı Adı';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Liman';
$lang['DirectAdmin.row_meta.host_name'] = 'Ana Bilgisayar Adı';
$lang['DirectAdmin.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Silme';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Silme';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Düzenle';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Düzenle';
$lang['DirectAdmin.manage.module_rows.count'] = '1$s / %2$s';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Ana Bilgisayar Adı';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['DirectAdmin.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['DirectAdmin.manage.module_rows_title'] = 'Sunucular';
$lang['DirectAdmin.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['DirectAdmin.add_module_row'] = 'Sunucu Ekle';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Atama';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Paylaşılan';
$lang['DirectAdmin.package_fields.ip'] = 'IP Adresi';
$lang['DirectAdmin.package_fields.package'] = 'DirectAdmin Paketi';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Bayi';
$lang['DirectAdmin.package_fields.type_user'] = 'Kullanıcı';
$lang['DirectAdmin.package_fields.type'] = 'Hesap Türü';
$lang['DirectAdmin.service_info.option_login'] = 'Giriş yap';
$lang['DirectAdmin.service_info.options'] = 'Seçenekler';
$lang['DirectAdmin.service_info.server'] = 'Sunucu';
$lang['DirectAdmin.service_info.password'] = 'Şifre';
$lang['DirectAdmin.service_info.username'] = 'Kullanıcı Adı';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Şifre Oluştur';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Şifreyi Güncelle';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Şifreyi Onayla';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Şifre Değiştir';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Şifre Oluştur';
$lang['DirectAdmin.service_field.email'] = 'E-posta';
$lang['DirectAdmin.service_field.password'] = 'Şifre';
$lang['DirectAdmin.service_field.username'] = 'Kullanıcı Adı';
$lang['DirectAdmin.service_field.domain'] = 'Etki Alanı';
$lang['DirectAdmin.server_groups.no_results'] = 'Sunucu grubu yoktur.';
$lang['DirectAdmin.servers.no_results'] = 'Sunucu yok.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['DirectAdmin.order_options.first'] = 'İlk Dolu Olmayan Sunucu';
$lang['DirectAdmin.tab_client_actions'] = 'Eylemler';
$lang['DirectAdmin.tab_stats'] = 'İstatistikler';
$lang['DirectAdmin.module_group'] = 'Sunucu Grubu';
$lang['DirectAdmin.module_row_plural'] = 'Sunucular';
$lang['DirectAdmin.module_row'] = 'Sunucu';
$lang['DirectAdmin.description'] = 'DirectAdmin, web sitelerinin yönetimini kolaylaştırmak için tasarlanmış grafiksel web tabanlı bir web barındırma kontrol panelidir.';
$lang['DirectAdmin.!error.change_package.type'] = 'Modül, kullanıcı ve bayi paketleri arasında geçiş yapmayı desteklemez.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Lütfen geçerli bir e-posta adresi girin.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Parola ve Parola Onayla eşleşmiyor.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Parolanın aşağıdakileri içerdiğinden emin olun: En az 12 karakter, en az 1 büyük harf karakteri A-Z, en az 1 küçük harf karakteri a-z, en az 1 sayı 0-9 ve şu kümeden en az 1 özel karakter: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Kullanıcı adı 4 ila 8 karakter uzunluğunda olmalıdır.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Kullanıcı adı yalnızca alfanümerik karakterler içerebilir.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Lütfen şu şekilde geçerli bir alan adı girin: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Bir IP adresi gereklidir.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Bir DirectAdmin paketi gereklidir.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Hesap Türü kullanıcı veya bayi olmalıdır.';
$lang['DirectAdmin.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['DirectAdmin.!error.name_servers.count'] = 'En az 2 ad sunucusu tanımlamanız gerekir.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Girilen ad sunucularından biri veya daha fazlası geçersiz.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'SSL kullan doğru veya yanlış olmalıdır.';
$lang['DirectAdmin.!error.password.format'] = 'Bir Parola girmelisiniz.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Bir Kullanıcı Adı girmelisiniz.';
$lang['DirectAdmin.!error.port.format'] = 'Bağlantı noktası bir sayı olmalıdır.';
$lang['DirectAdmin.!error.host_name.format'] = 'Ana Bilgisayar Adı geçersiz görünüyor.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['DirectAdmin.name'] = 'DirectAdmin';

==> blesta-5.11.4.zip: blesta/components/modules/direct_admin/language/tr_tr/direct_admin.php <==
<?php
/**
 * Direct Admin
 *
 * @package blesta
 * @subpackage blesta.language.tr_tr
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['DirectAdmin.tab_client_stats.no_results'] = 'İstatistiki bilgiler şu anda mevcut değildir.';
$lang['DirectAdmin.tab_client_stats.info_heading.value'] = 'Değer';
$lang['DirectAdmin.tab_client_stats.info_heading.field'] = 'Saha';
$lang['DirectAdmin.tab_client_stats.info_title'] = 'Bilgi';
$lang['DirectAdmin.tab_client_stats'] = 'İstatistikler';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_password'] = 'Şifre';
$lang['DirectAdmin.edit_row.add_btn'] = 'Sunucuyu Düzenle';
$lang['DirectAdmin.edit_row.notes_title'] = 'Notlar';
$lang['DirectAdmin.edit_row.remove_name_server'] = 'Kaldırmak';
$lang['DirectAdmin.edit_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['DirectAdmin.edit_row.name_server_col'] = 'İsim Sunucusu';
$lang['DirectAdmin.edit_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['DirectAdmin.edit_row.name_servers_title'] = 'İsim Sunucuları';
$lang['DirectAdmin.edit_row.basic_title'] = 'Temel Ayarlar';
$lang['DirectAdmin.edit_row.box_title'] = 'DirectAdmin Sunucusunu Düzenleme';
$lang['DirectAdmin.add_row.add_btn'] = 'Sunucu Ekle';
$lang['DirectAdmin.add_row.notes_title'] = 'Notlar';
$lang['DirectAdmin.add_row.remove_name_server'] = 'Kaldırmak';
$lang['DirectAdmin.add_row.name_server_host_col'] = 'Ana bilgisayar adı';
$lang['DirectAdmin.add_row.name_server_col'] = 'İsim Sunucusu';
$lang['DirectAdmin.add_row.name_server_btn'] = 'Ek Ad Sunucusu Ekleme';
$lang['DirectAdmin.add_row.name_servers_title'] = 'İsim Sunucuları';
$lang['DirectAdmin.add_row.basic_title'] = 'Temel Ayarlar';
$lang['DirectAdmin.add_row.box_title'] = 'DirectAdmin Sunucusu Ekleme';
$lang['DirectAdmin.row_meta.name_server'] = 'İsim sunucusu %1$s';
$lang['DirectAdmin.row_meta.account_limit'] = 'Hesap Limiti';
$lang['DirectAdmin.row_meta.use_ssl'] = 'API\'ye bağlanırken SSL kullanın (önerilir)';
$lang['DirectAdmin.row_meta.password'] = 'Şifre';
$lang['DirectAdmin.row_meta.user_name'] = 'Kullanıcı Adı';
$lang['DirectAdmin.row_meta.default_port'] = '2222';
$lang['DirectAdmin.row_meta.port'] = 'Liman';
$lang['DirectAdmin.row_meta.host_name'] = 'Ana Bilgisayar Adı';
$lang['DirectAdmin.row_meta.server_name'] = 'Sunucu Etiketi';
$lang['DirectAdmin.manage.module_groups.confirm_delete'] = 'Bu sunucu grubunu silmek istediğinizden emin misiniz?';
$lang['DirectAdmin.manage.module_rows.confirm_delete'] = 'Bu sunucuyu silmek istediğinizden emin misiniz?';
$lang['DirectAdmin.manage.module_groups.delete'] = 'Silme';
$lang['DirectAdmin.manage.module_rows.delete'] = 'Silme';
$lang['DirectAdmin.manage.module_groups.edit'] = 'Düzenle';
$lang['DirectAdmin.manage.module_rows.edit'] = 'Düzenle';
$lang['DirectAdmin.manage.module_groups_heading.options'] = 'Seçenekler';
$lang['DirectAdmin.manage.module_groups_heading.servers'] = 'Sunucu Sayısı';
$lang['DirectAdmin.manage.module_groups_heading.name'] = 'Grup Adı';
$lang['DirectAdmin.manage.module_rows_heading.options'] = 'Seçenekler';
$lang['DirectAdmin.manage.module_rows_heading.accounts'] = 'Hesaplar';
$lang['DirectAdmin.manage.module_rows_heading.host_name'] = 'Ana Bilgisayar Adı';
$lang['DirectAdmin.manage.module_rows_heading.name'] = 'Sunucu Etiketi';
$lang['DirectAdmin.manage.module_groups_title'] = 'Sunucu Grupları';
$lang['DirectAdmin.manage.module_rows_title'] = 'Sunucular';
$lang['DirectAdmin.add_module_group'] = 'Sunucu Grubu Ekleme';
$lang['DirectAdmin.add_module_row'] = 'Sunucu Ekle';
$lang['DirectAdmin.package_fields.ip_assign'] = 'Atama';
$lang['DirectAdmin.package_fields.ip_shared'] = 'Paylaşılan';
$lang['DirectAdmin.package_fields.ip'] = 'IP Adresi';
$lang['DirectAdmin.package_fields.package'] = 'DirectAdmin Paketi';
$lang['DirectAdmin.package_fields.type_reseller'] = 'Bayi';
$lang['DirectAdmin.package_fields.type_user'] = 'Kullanıcı';
$lang['DirectAdmin.package_fields.type'] = 'Hesap Türü';
$lang['DirectAdmin.service_info.option_login'] = 'Giriş yap';
$lang['DirectAdmin.service_info.options'] = 'Seçenekler';
$lang['DirectAdmin.service_info.server'] = 'Sunucu';
$lang['DirectAdmin.service_info.password'] = 'Şifre';
$lang['DirectAdmin.service_info.username'] = 'Kullanıcı Adı';
$lang['DirectAdmin.tab_client_actions.text_generate_password'] = 'Şifre Oluştur';
$lang['DirectAdmin.tab_client_actions.field_password_submit'] = 'Şifreyi Güncelle';
$lang['DirectAdmin.tab_client_actions.field_direct_admin_confirm_password'] = 'Şifreyi Onayla';
$lang['DirectAdmin.tab_client_actions.change_password'] = 'Şifre Değiştir';
$lang['DirectAdmin.service_field.text_generate_password'] = 'Şifre Oluştur';
$lang['DirectAdmin.service_field.email'] = 'E-posta';
$lang['DirectAdmin.service_field.password'] = 'Şifre';
$lang['DirectAdmin.service_field.username'] = 'Kullanıcı Adı';
$lang['DirectAdmin.service_field.domain'] = 'Etki Alanı';
$lang['DirectAdmin.server_groups.no_results'] = 'Sunucu grubu yoktur.';
$lang['DirectAdmin.servers.no_results'] = 'Sunucu yok.';
$lang['DirectAdmin.order_options.roundrobin'] = 'Sunucular Arasında Eşit Olarak Dağıtın';
$lang['DirectAdmin.order_options.first'] = 'İlk Dolu Olmayan Sunucu';
$lang['DirectAdmin.tab_client_actions'] = 'Eylemler';
$lang['DirectAdmin.tab_stats'] = 'İstatistikler';
$lang['DirectAdmin.module_group'] = 'Sunucu Grubu';
$lang['DirectAdmin.module_row_plural'] = 'Sunucular';
$lang['DirectAdmin.module_row'] = 'Sunucu';
$lang['DirectAdmin.description'] = 'DirectAdmin, web sitelerinin yönetimini kolaylaştırmak için tasarlanmış grafiksel web tabanlı bir web barındırma kontrol panelidir.';
$lang['DirectAdmin.!error.change_package.type'] = 'Modül, kullanıcı ve bayi paketleri arasında geçiş yapmayı desteklemez.';
$lang['DirectAdmin.!error.direct_admin_email.format'] = 'Lütfen geçerli bir e-posta adresi girin.';
$lang['DirectAdmin.!error.direct_admin_password.matches'] = 'Parola ve Parola Onayla eşleşmiyor.';
$lang['DirectAdmin.!error.direct_admin_password.format'] = 'Parolanın aşağıdakileri içerdiğinden emin olun: En az 12 karakter, en az 1 büyük harf karakteri A-Z, en az 1 küçük harf karakteri a-z, en az 1 sayı 0-9 ve şu kümeden en az 1 özel karakter: !"#$%&\'()*+,-./:;<=>?@[]^_` {|}';
$lang['DirectAdmin.!error.direct_admin_username.length'] = 'Kullanıcı adı 4 ila 8 karakter uzunluğunda olmalıdır.';
$lang['DirectAdmin.!error.direct_admin_username.format'] = 'Kullanıcı adı yalnızca alfanümerik karakterler içerebilir.';
$lang['DirectAdmin.!error.direct_admin_domain.format'] = 'Lütfen şu şekilde geçerli bir alan adı girin: domain.com';
$lang['DirectAdmin.!error.meta[ip].empty'] = 'Bir IP adresi gereklidir.';
$lang['DirectAdmin.!error.meta[package].empty'] = 'Bir DirectAdmin paketi gereklidir.';
$lang['DirectAdmin.!error.meta[type].format'] = 'Hesap Türü kullanıcı veya bayi olmalıdır.';
$lang['DirectAdmin.!error.api.internal'] = 'Dahili bir hata oluştu veya sunucu isteğe yanıt vermedi.';
$lang['DirectAdmin.!error.name_servers.count'] = 'En az 2 ad sunucusu tanımlamanız gerekir.';
$lang['DirectAdmin.!error.name_servers.valid'] = 'Girilen ad sunucularından biri veya daha fazlası geçersiz.';
$lang['DirectAdmin.!error.account_limit.valid'] = 'Hesap Sınırı boş bırakılmalı (sınırsız hesaplar için) veya bir tamsayı değerine ayarlanmalıdır.';
$lang['DirectAdmin.!error.use_ssl.format'] = 'SSL kullan doğru veya yanlış olmalıdır.';
$lang['DirectAdmin.!error.password.format'] = 'Bir Parola girmelisiniz.';
$lang['DirectAdmin.!error.user_name.empty'] = 'Bir Kullanıcı Adı girmelisiniz.';
$lang['DirectAdmin.!error.port.format'] = 'Bağlantı noktası bir sayı olmalıdır.';
$lang['DirectAdmin.!error.host_name.format'] = 'Ana Bilgisayar Adı geçersiz görünüyor.';
$lang['DirectAdmin.!error.server_name.empty'] = 'Bir Sunucu Etiketi girmelisiniz.';
$lang['DirectAdmin.name'] = 'DirectAdmin';
$lang['DirectAdmin.manage.module_rows.count'] = '%1$s / %2$s';
$lang['DirectAdmin.row_meta.ip_address'] = 'IP Adresi';
$lang['DirectAdmin.!error.ip_address.format'] = 'IP Adresi geçersiz görünüyor.';
